pub struct LoadEnvOptions {
pub prefix: Option<String>,
pub use_namespace: bool,
}Expand description
Options for loading secrets into the environment.
Fields
prefix: Option<String>Prefix to prepend to environment variable names. If strictly empty or None, no prefix is added.
use_namespace: boolWhether to include the namespace in the environment variable name.
Implementations
Sourceimpl LoadEnvOptions
impl LoadEnvOptions
Sourcepub fn with_prefix(self, prefix: impl Into<String>) -> Self
pub fn with_prefix(self, prefix: impl Into<String>) -> Self
Set the prefix.
Sourcepub fn with_namespace(self, use_namespace: bool) -> Self
pub fn with_namespace(self, use_namespace: bool) -> Self
Set whether to use the namespace.